@@ -18,10 +18,11 @@ use indexmap::IndexSet;
 use petgraph::EdgeDirection;
 #[cfg(feature = "concurrent")]
 use rayon::iter::ParallelIterator;
+use std::sync::atomic::Ordering;
 use swc_atoms::js_word;
 use swc_common::{sync::Lock, FileName, SyntaxContext, DUMMY_SP};
 use swc_ecma_ast::*;
-use swc_ecma_utils::{find_ids, prepend, private_ident};
+use swc_ecma_utils::{find_ids, prepend, private_ident, quote_ident, ExprFactory};
 use swc_ecma_visit::{noop_fold_type, noop_visit_mut_type, Fold, VisitMut, VisitMutWith};
 use EdgeDirection::Outgoing;
 
@@ -906,6 +907,89 @@ where
                         ref src,
                         ..
                     })) => {
+                        if let Some(export_src) = src {
+                            if let Some((src, _)) = info
+                                .exports
+                                .reexports
+                                .iter()
+                                .find(|s| s.0.src.value == export_src.value)
+                            {
+                                let dep = self.scope.get_module(src.module_id).unwrap();
+                                if !dep.is_es6 {
+                                    dep.helpers.require.store(true, Ordering::SeqCst);
+
+                                    let mut vars = vec![];
+                                    let mod_var = private_ident!("_cjs_module_");
+
+                                    vars.push(VarDeclarator {
+                                        span: DUMMY_SP,
+                                        name: Pat::Ident(mod_var.clone().into()),
+                                        init: Some(Box::new(Expr::Call(CallExpr {
+                                            span: DUMMY_SP,
+                                            callee: Ident::new(
+                                                "load".into(),
+                                                DUMMY_SP.with_ctxt(dep.export_ctxt()),
+                                            )
+                                            .as_callee(),
+                                            args: Default::default(),
+                                            type_args: Default::default(),
+                                        }))),
+                                        definite: Default::default(),
+                                    });
+                                    for s in specifiers {
+                                        match s {
+                                            ExportSpecifier::Namespace(s) => {
+                                                vars.push(VarDeclarator {
+                                                    span: s.span,
+                                                    name: Pat::Ident(s.name.clone().into()),
+                                                    init: Some(Box::new(Expr::Ident(
+                                                        mod_var.clone(),
+                                                    ))),
+                                                    definite: Default::default(),
+                                                });
+                                            }
+                                            ExportSpecifier::Default(s) => {
+                                                vars.push(VarDeclarator {
+                                                    span: DUMMY_SP,
+                                                    name: Pat::Ident(s.exported.clone().into()),
+                                                    init: Some(Box::new(
+                                                        mod_var
+                                                            .clone()
+                                                            .make_member(quote_ident!("default")),
+                                                    )),
+                                                    definite: Default::default(),
+                                                });
+                                            }
+                                            ExportSpecifier::Named(s) => {
+                                                vars.push(VarDeclarator {
+                                                    span: s.span,
+                                                    name: Pat::Ident(
+                                                        s.exported.clone().unwrap().into(),
+                                                    ),
+                                                    init: Some(Box::new(
+                                                        mod_var.clone().make_member(s.orig.clone()),
+                                                    )),
+                                                    definite: Default::default(),
+                                                });
+                                            }
+                                        }
+                                    }
+
+                                    if !vars.is_empty() {
+                                        new.push(ModuleItem::Stmt(Stmt::Decl(Decl::Var(
+                                            VarDecl {
+                                                span: DUMMY_SP,
+                                                kind: VarDeclKind::Const,
+                                                declare: Default::default(),
+                                                decls: vars,
+                                            },
+                                        ))));
+                                    }
+                                    continue;
+                                }
+                            }
+                        }
+
                         for s in specifiers {
                             match s {
                                 ExportSpecifier::Named(ExportNamedSpecifier {
